# maihem

The **maihem** python package creates AI agents that automatically test your conversational LLM applications.

- Automatically find failures in your LLM applications before your users do
- Build LLM applications that you and others can trust with our Quality Assurance Reports

To install the API, run the following command:
```
pip install maihem
```

Check out our [documentation](https://docs.maihem.ai/quickstart) to learn how to use **maihem**.
